Univariate Volatility Models
----------------------------

``arch.univaraite`` provides both high-level (:func:`~arch.univariate.arch_model`) and low-level
methods (see :ref:`mean-models`) to specify models. All models can be used to produce forecasts
either analytically (when tractable) or using simulation-based methods (Monte Carlo or
residual Bootstrap).

.. module::arch.univariate

.. toctree::
    :maxdepth: 1

    Introduction <introduction>
    Examples <univariate_volatility_modeling.ipynb>
    Forecasting <forecasting>
    Forecasting Examples <univariate_volatility_forecasting.ipynb>
    Forecasting Scenarios <univariate_volatility_scenarios.ipynb>
    Forecasting with Exogenous Variables <univariate_forecasting_with_exogenous_variables.ipynb>
    Mean Models <mean>
    Volatility Processes <volatility>
    Using the Fixed Variance Process <univariate_using_fixed_variance.ipynb>
    Distributions <distribution>
    Results <results>
    Utilities <utility>
    Background and References <background>
